//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/List/SamplesQListView.cpp
//! @brief     Implements class SamplesQListView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/List/SamplesQListView.h"
#include "Base/Util/SysUtil.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/Model/Sample/SampleItem.h"
#include "GUI/Model/Sample/SamplesSet.h"
#include "GUI/View/Layout/ApplicationSettings.h"
#include "GUI/View/List/SamplesQModel.h"
#include "GUI/View/Setup/FrameActions.h"
#include "GUI/View/Widget/ListItemDelegate.h"
#include <QAction>

SamplesQListView::SamplesQListView(SamplesQModel* model)
    : m_model(model)
{
    setMaximumWidth(200);
    setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

    setModel(m_model);
    setSelectionMode(QAbstractItemView::SingleSelection);

    setItemDelegate(new ListItemDelegate(this));

    connect(selectionModel(), &QItemSelectionModel::currentChanged, this,
            &SamplesQListView::onCurrentChanged);
}

void SamplesQListView::createNewSample()
{
    const QModelIndex newIndex = m_model->createSample();
    setCurrentIndex(newIndex);
    gDoc->setModified();
}

void SamplesQListView::createSampleFromLibrary(const QString& classname, const QString& title,
                                               const QString& description)
{
    const QModelIndex newIndex = m_model->createSampleFromExamples(classname, title, description);
    if (newIndex.isValid()) {
        setCurrentIndex(newIndex);
        gDoc->setModified();
    }
}

void SamplesQListView::importSampleFromPython()
{
#ifdef BORNAGAIN_PYTHON
    const QModelIndex newIndex = m_model->createSampleFromPython();
    if (newIndex.isValid()) {
        setCurrentIndex(newIndex);
        gDoc->setModified();
    }
#endif
}

void SamplesQListView::onCurrentChanged(const QModelIndex& index)
{
    gDoc->samplesModifier()->setCurrentIndex(index.row());
    emit currentSampleChanged(m_model->itemForIndex(index));
}
